Module types

Module types 

Structs

BatchRequest
A request object for a batch of read operations.
BatchResponse
The response from a batch read operation.
DbStats
A struct to hold database statistics.
QueryOptions
Defines query modifiers like sorting, limiting, and pagination.
RecordSet
Represents a set of records returned from a query.

Enums

Direction
Enum for sorting direction.
Filter
Defines a filter for querying records (the “WHERE” clause).

Type Aliases

Record
A type alias for a single record, represented as a map of field names to JSON values.